diff --git a/builds/win32/msvc9/btyacc.vcproj b/builds/win32/msvc9/btyacc.vcproj
index 895e7347fe..f64b83fab7 100644
--- a/builds/win32/msvc9/btyacc.vcproj
+++ b/builds/win32/msvc9/btyacc.vcproj
@@ -44,7 +44,7 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
#endif
+#if defined(_MSC_VER) && _MSC_VER >= 1500
+// ISO C++ conformant names
+#define unlink _unlink
+#define mktemp _mktemp
+#define strdup _strdup
+#endif
+
char dflag;
char lflag;
char rflag;
diff --git a/extern/btyacc/readskel.c b/extern/btyacc/readskel.c
index ae6bd4031f..b127f118f5 100644
--- a/extern/btyacc/readskel.c
+++ b/extern/btyacc/readskel.c
@@ -10,7 +10,7 @@ static char **ap, **ap_end, **ap_start;
static void add_ptr(char *p)
{
if (ap == ap_end) {
- int size = CHUNK;
+ unsigned int size = CHUNK;
char **nap;
while ((ap-ap_start) * sizeof(char *) >= size)
size = size * 2;
diff --git a/extern/btyacc/mstring.c b/extern/btyacc/mstring.c
index 9e119a7303..6c33d7d970 100644
--- a/extern/btyacc/mstring.c
+++ b/extern/btyacc/mstring.c
@@ -2,9 +2,10 @@
#include "mstring.h"
#include
-/* parameters about string length. START is the starting size and
-** START+TAIL should be a power of two */
-#define START 24
+/* parameters about string length. START_STR is the starting size and
+** START_STR+TAIL should be a power of two
+Renamed to START_STR because START is defined in defs.h with another value */
+#define START_STR 24
#define TAIL 8
void msprintf(struct mstring *s, const char *fmt, ...)
@@ -51,8 +52,8 @@ int mputchar(struct mstring *s, int ch)
struct mstring *msnew(void) {
struct mstring *n = malloc(sizeof(struct mstring));
- if (n && (n->base = n->ptr = malloc(START)))
- n->end = n->base + START;
+ if (n && (n->base = n->ptr = malloc(START_STR)))
+ n->end = n->base + START_STR;
else if (n) {
free(n);
n = 0; }